==> order-center-api-3.1.0-CLOUD-DEV-20230831.104739-111-sources.jar: com/tydic/dyc/oc/service/domainservice/bo/UocGetApprovalOrderDetailServiceRspBo.java <==
package com.tydic.dyc.oc.service.domainservice.bo;

import com.tydic.dyc.base.bo.BaseRspBo;
import com.tydic.dyc.oc.service.common.bo.UocBaseOrderAccessoryTypeDetailBo;
import com.tydic.dyc.oc.service.saleorder.bo.UocGetSaleOrderDetailServiceRspItemBo;
import com.tydic.dyc.oc.service.saleorder.bo.UocGetSaleOrderDetailServiceRspPorcBo;
import com.tydic.dyc.oc.service.saleorder.bo.UocGetSaleOrderDetailServiceRspReceiverAddressBo;
import com.tydic.dyc.oc.service.saleorder.bo.UocGetSaleOrderDetailServiceRspStakeholderBo;
import lombok.Data;

import java.io.Serializable;
import java.util.Date;
import java.util.List;

/*
 * @Author lsl
 * @Description //TODO 查询审批单详情出参bo
 * @Date 17:59 2023/8/20
 * @Param 
 * @return 
 */
@Data
public class UocGetApprovalOrderDetailServiceRspBo extends BaseRspBo{
    private static final long serialVersionUID = -8205881360023046995L;
    
    //审批单id
    private Long auditOrderId;
    
    //订单id
    private Long orderId;
    
    //审批单编号
    private String auditOrderCode;
    
    /**
     * 收获人地址信息
     */
    private UocGetSaleOrderDetailServiceRspReceiverAddressBo receiverAddressBo;
    
    /**
     * 三方信息
     */
    private UocGetSaleOrderDetailServiceRspStakeholderBo stakeholderBo;
    
    /**
     * 附件信息
     */
    private List<UocBaseOrderAccessoryTypeDetailBo> accessoryList;
    
    /**
     * 销售单明细信息
     */
    private List<UocGetSaleOrderDetailServiceRspItemBo> saleOrderDetailItemBoList;
    
    /*订单创建时间*/
    private Date createOrderTime;
    
    /**
     * 期望送达时间
     */
    private Date sendTime;
    
    /**
     * 备注
     */
    private String remark;
    
    /**
     * 预算模式
     */
    private String budgetModelCode;
    private String budgetModelName;
    
    /**
     * 财务事项申请单id
     */
    private String financialId;
    /**
     * 财务事项申请单名称
     */
    private String financialName;
    
    
    /**
     * 成本中心id
     */
    private String costCenterId;
    /**
     * 成本中心名称
     */
    private String costCenterName;
    
    
    /**
     * 归口部门
     */
    private String relevantDeptName;
    
    
    
    /**
     * 预算项目id
     */
    private String budgetProjectId;
    /**
     * 预算项目名称
     */
    private String budgetProjectName;
    
    
    /**
     * 是否统采订单 0:是；1不是
     */
    private String unifiedPurOrderFlag;
    
    
    /**
     * 服务失效时间
     */
    private String serviceFailTime;
    /**
     * 服务生效时间
     */
    private String serviceEffectiveTime;
    /**
     * 审批流程数据
     */
    private UocGetSaleOrderDetailServiceRspPorcBo auditProcInst;
}

==> order-center-api-3.2.3-CLOUD-DEV-20241128.130707-27-sources.jar: com/tydic/dyc/oc/service/domainservice/bo/UocGetApprovalOrderDetailServiceRspBo.java <==
package com.tydic.dyc.oc.service.domainservice.bo;

import com.tydic.dyc.base.bo.BaseRspBo;
import com.tydic.dyc.oc.service.common.bo.UocBaseOrderAccessoryTypeDetailBo;
import com.tydic.dyc.oc.service.saleorder.bo.UocGetSaleOrderDetailServiceRspItemBo;
import com.tydic.dyc.oc.service.saleorder.bo.UocGetSaleOrderDetailServiceRspPorcBo;
import com.tydic.dyc.oc.service.saleorder.bo.UocGetSaleOrderDetailServiceRspReceiverAddressBo;
import com.tydic.dyc.oc.service.saleorder.bo.UocGetSaleOrderDetailServiceRspStakeholderBo;
import lombok.Data;

import java.io.Serializable;
import java.math.BigDecimal;
import java.util.Date;
import java.util.List;

/*
 * @Author lsl
 * @Description //TODO 查询审批单详情出参bo
 * @Date 17:59 2023/8/20
 * @Param 
 * @return 
 */
@Data
public class UocGetApprovalOrderDetailServiceRspBo extends BaseRspBo{
    private static final long serialVersionUID = -8205881360023046995L;
    
    //审批单id
    private Long auditOrderId;
    
    //订单id
    private Long orderId;
    
    //审批单编号
    private String auditOrderCode;
    
    /**
     * 收获人地址信息
     */
    private UocGetSaleOrderDetailServiceRspReceiverAddressBo receiverAddressBo;
    
    /**
     * 三方信息
     */
    private UocGetSaleOrderDetailServiceRspStakeholderBo stakeholderBo;
    
    /**
     * 附件信息
     */
    private List<UocBaseOrderAccessoryTypeDetailBo> accessoryList;
    
    /**
     * 销售单明细信息
     */
    private List<UocGetSaleOrderDetailServiceRspItemBo> saleOrderDetailItemBoList;
    
    /*订单创建时间*/
    private Date createOrderTime;
    
    /**
     * 期望送达时间
     */
    private Date sendTime;
    
    /**
     * 备注
     */
    private String remark;
    
    /**
     * 预算模式
     */
    private String budgetModelCode;
    private String budgetModelName;
    
    /**
     * 财务事项申请单id
     */
    private String financialId;
    /**
     * 财务事项申请单名称
     */
    private String financialName;
    
    
    /**
     * 成本中心id
     */
    private String costCenterId;
    /**
     * 成本中心名称
     */
    private String costCenterName;
    
    
    /**
     * 归口部门
     */
    private String relevantDeptName;
    
    
    
    /**
     * 预算项目id
     */
    private String budgetProjectId;
    /**
     * 预算项目名称
     */
    private String budgetProjectName;
    
    
    /**
     * 是否统采订单 0:是；1不是
     */
    private String unifiedPurOrderFlag;
    
    
    /**
     * 服务失效时间
     */
    private String serviceFailTime;
    /**
     * 服务生效时间
     */
    private String serviceEffectiveTime;
    /**
     * 审批流程数据
     */
    private UocGetSaleOrderDetailServiceRspPorcBo auditProcInst;
    
    
    private BigDecimal totalPurchaseFee;
    
    private BigDecimal totalSaleFee;
    
    private BigDecimal totalTransFee;
    /**
     * 订单名称
     */
    private String orderName;
}
